import { Component, OnInit } from "@angular/core";

@Component({
    selector: "branch-admin",
    templateUrl: "branch.component.html",
})
export class BranchComponent implements OnInit {
    ngOnInit() {}
}
